==> kadu_0.12.3.orig.tar.bz2: kadu-0.12.3/plugins/history/translations/history_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historia rozmów</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Zapisuj wiadomości w historii</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Zapisuj rozmowy z anonimami</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Zapisuj zmiany statusów</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Zapisuje zmiany statusów w historii</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Zapisuj tylko statusy z opisem</translation>
    </message>
    <message>
        <source>Quotation</source>
        <translation>Cytowanie</translation>
    </message>
    <message>
        <source>Quote message in chat window</source>
        <translation>Cytowanie historii w oknie rozmowy</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Ogólne</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Pokaż historię</translation>
    </message>
    <message>
        <source>Do not quote messages older than</source>
        <translation>Nie cytuj wiadomości starszych niż</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Wyczyść historię rozmów</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Wyczyść historię</translation>
    </message>
    <message>
        <source>%1 day(s) %2 hour(s)</source>
        <translation>%1 dzień(dni) %2 godzina(y)</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation>Przechowywanie historii rozmów</translation>
    </message>
</context>
<context>
    <name>HistoryChatDataWindowAddons</name>
    <message>
        <source>Store history</source>
        <translation>Przechowywanie historii rozmów</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Usuń wpisy</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Czy na pewno chcesz usunąć historię?</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Wyczyść historię statusów</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Wyczyść historię SMSów</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Czaty</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statusy</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Chat history</source>
        <translation>Historia rozmów</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Szukaj: </translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Czaty</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation>- Wszystkie rozmowy -</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statusy</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation>- Wszyscy znajomi -</translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>Sms-y</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation>- Wszyscy odbiorcy -</translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Wg daty</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Znaleziony</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Znajomy</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Pokaż historię rozmów</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Wyświetl ostatnie %1 wiadomości</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Wyświetl wiadomości od wczoraj</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Wyświetl wiadomości z ostatniego tygodnia</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Wyświetl wiadomości z ostatnich 30 dni</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Wyświetl całą historię</translation>
    </message>
</context>
</TS>

==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/history/translations/history_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>Chat</source>
        <translation>Rozmowa</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Chats History</source>
        <translation>Historia rozmów</translation>
    </message>
    <message>
        <source>Save messages in history</source>
        <translation>Zapisuj wiadomości w historii</translation>
    </message>
    <message>
        <source>Save chats with anonymous users</source>
        <translation>Zapisuj rozmowy z anonimami</translation>
    </message>
    <message>
        <source>Status Changes</source>
        <translation>Zmiany statusów</translation>
    </message>
    <message>
        <source>Save status changes</source>
        <translation>Zapisuj zmiany statusów</translation>
    </message>
    <message>
        <source>Save status changes in history</source>
        <translation>Zapisuje zmiany statusów w historii</translation>
    </message>
    <message>
        <source>Save status only with description</source>
        <translation>Zapisuj tylko statusy z opisem</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Skróty</translation>
    </message>
    <message>
        <source>View history</source>
        <translation>Pokaż historię</translation>
    </message>
    <message>
        <source>Save chats in history</source>
        <translation>Zapisuj historię rozmów</translation>
    </message>
    <message>
        <source>History in chat window</source>
        <translation>Historia w oknie rozmowy</translation>
    </message>
    <message>
        <source>Show messages from history since</source>
        <translation>Pokaż wiadomości z historii od</translation>
    </message>
    <message>
        <source>Choose time period in which messages can be quoted in chat window</source>
        <translation>Wybierz okres z którego będą wyświetlone wiadomości w oknie rozmowy</translation>
    </message>
    <message>
        <source>yesterday</source>
        <translation>wczoraj</translation>
    </message>
    <message>
        <source>last week</source>
        <translation>ostatniego tygodnia</translation>
    </message>
    <message>
        <source>last month</source>
        <translation>ostatniego miesiąca</translation>
    </message>
    <message>
        <source>Limit number of messages from history</source>
        <translation>Limit ilości wiadomości z historii</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Zachowanie</translation>
    </message>
    <message>
        <source>Chat window</source>
        <translation>Okno rozmowy</translation>
    </message>
</context>
<context>
    <name>BuddyHistoryDeleteHandler</name>
    <message>
        <source>Chat history</source>
        <translation>Historia rozmów</translation>
    </message>
</context>
<context>
    <name>ChatHistoryTab</name>
    <message>
        <source>&amp;Clear Chat History</source>
        <translation>&amp;Wyczyść historię rozmów</translation>
    </message>
</context>
<context>
    <name>History</name>
    <message>
        <source>Clear History</source>
        <translation>Wyczyść historię</translation>
    </message>
</context>
<context>
    <name>HistoryBuddyConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Zapisuj historię rozmów</translation>
    </message>
</context>
<context>
    <name>HistoryChatConfigurationWidget</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Store history</source>
        <translation>Zapisuj historię rozmów</translation>
    </message>
</context>
<context>
    <name>HistoryMessagesTab</name>
    <message>
        <source>&amp;Remove entries</source>
        <translation>&amp;Usuń wpisy</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Kadu</source>
        <translation>Kadu</translation>
    </message>
    <message>
        <source>Do you really want to delete history?</source>
        <translation>Czy na pewno chcesz usunąć historię?</translation>
    </message>
    <message>
        <source>Delete history</source>
        <translation>Usuń historię</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>HistoryQueryResultsModel</name>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Tytuł</translation>
    </message>
</context>
<context>
    <name>HistoryWindow</name>
    <message>
        <source>History</source>
        <translation>Historia</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>&amp;Clear Status History</source>
        <translation>&amp;Wyczyść historię statusów</translation>
    </message>
    <message>
        <source>&amp;Clear SMS History</source>
        <translation>&amp;Wyczyść historię SMSów</translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Czaty</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statusy</translation>
    </message>
    <message>
        <source>SMS</source>
        <translation>SMS</translation>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search for:</source>
        <translation>Szukaj: </translation>
    </message>
    <message>
        <source>Chats</source>
        <translation>Czaty</translation>
    </message>
    <message>
        <source> - All chats - </source>
        <translation>- Wszystkie rozmowy -</translation>
    </message>
    <message>
        <source>Statuses</source>
        <translation>Statusy</translation>
    </message>
    <message>
        <source> - All buddies - </source>
        <translation>- Wszyscy znajomi -</translation>
    </message>
    <message>
        <source>Smses</source>
        <translation>Sms-y</translation>
    </message>
    <message>
        <source> - All recipients - </source>
        <translation>- Wszyscy odbiorcy -</translation>
    </message>
    <message>
        <source>By date</source>
        <translation>Wg daty</translation>
    </message>
    <message>
        <source>to</source>
        <translation>do</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Znaleziony</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Czat</translation>
    </message>
    <message>
        <source>Buddy</source>
        <translation>Znajomy</translation>
    </message>
    <message>
        <source>Recipient</source>
        <translation>Odbiorca</translation>
    </message>
</context>
<context>
    <name>ShowHistoryActionDescription</name>
    <message>
        <source>View Chat History</source>
        <translation>Pokaż historię rozmów</translation>
    </message>
    <message>
        <source>Show last %1 messages</source>
        <translation>Wyświetl ostatnie %1 wiadomości</translation>
    </message>
    <message>
        <source>Show messages since yesterday</source>
        <translation>Wyświetl wiadomości od wczoraj</translation>
    </message>
    <message>
        <source>Show messages from last 7 days</source>
        <translation>Wyświetl wiadomości z ostatniego tygodnia</translation>
    </message>
    <message>
        <source>Show messages from last 30 days</source>
        <translation>Wyświetl wiadomości z ostatnich 30 dni</translation>
    </message>
    <message>
        <source>Show whole history</source>
        <translation>Wyświetl całą historię</translation>
    </message>
</context>
</TS>
